﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ScheduleWebApi.Models;
using System.Web.Services;
using System.Web.Script.Services;
using Newtonsoft.Json;

namespace ScheduleWebApi
{
    public partial class _Default : Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            List<Rooms> owners = new List<Rooms>();
            owners.Add(new Rooms { text = "Nancy", id = "1", groupId = "1", color = "#ffaa00" });
            owners.Add(new Rooms { text = "Steven", id = "2", groupId = "1", color = "#f8a398" });
            owners.Add(new Rooms { text = "Michael", id = "3", groupId = "2", color = "#7499e1" });
            Schedule1.Resources[0].ResourceSettings.DataSource = owners;
        }

        public class Rooms
        {
            public string text { set; get; }
            public string id { set; get; }
            public string groupId { set; get; }
            public string color { set; get; }
        }

        [WebMethod]
        [ScriptMethod(ResponseFormat = ResponseFormat.Json)]
        public static List<ScheduleAppointment> GetData()
        {
            return new ScheduleDataDataContext().ScheduleAppointments.Take(10).ToList();
        }


        [WebMethod]
        [ScriptMethod(ResponseFormat = ResponseFormat.Json)]
        public static List<ScheduleAppointment> CrudResult(List<ScheduleAppointment> added, List<ScheduleAppointment> changed, List<ScheduleAppointment> deleted)
        {
            ScheduleDataDataContext db = new ScheduleDataDataContext();
            int intMax = db.ScheduleAppointments.ToList().Count > 0 ? db.ScheduleAppointments.ToList().Max(p => p.Id) : 0;
            if (added != null && added.Count > 0)
            {
                for (int i = 0; i < added.Count; i++)
                {
                    intMax = db.ScheduleAppointments.ToList().Count > 0 ? db.ScheduleAppointments.ToList().Max(p => p.Id) : 0;
                    var value = added[i];
                    DateTime startTime = Convert.ToDateTime(value.StartTime);
                    DateTime endTime = Convert.ToDateTime(value.EndTime);
                    ScheduleAppointment appoint = new ScheduleAppointment();
                    appoint.Id = intMax + 1;
                    appoint.Subject = value.Subject;
                    appoint.StartTime = startTime;
                    appoint.EndTime = endTime;
                    appoint.AllDay = value.AllDay;
                    appoint.Recurrence = value.Recurrence;
                    appoint.RecurrenceRule = value.RecurrenceRule;
                    appoint.OwnerId = value.OwnerId;
                    db.ScheduleAppointments.InsertOnSubmit(appoint);
                    db.SubmitChanges();
                }                
            }
            if (changed != null && changed.Count > 0)
            {
                var filterData = db.ScheduleAppointments.Where(c => c.Id == Convert.ToInt32(changed[0].Id));
                if (filterData.Count() > 0)
                {
                    var value = changed[0];
                    DateTime startTime = Convert.ToDateTime(value.StartTime);
                    DateTime endTime = Convert.ToDateTime(value.EndTime);
                    ScheduleAppointment appoint = db.ScheduleAppointments.Single(A => A.Id == Convert.ToInt32(value.Id));
                    appoint.StartTime = startTime;
                    appoint.EndTime = endTime;
                    appoint.Subject = value.Subject;
                    appoint.AllDay = value.AllDay;
                    appoint.Recurrence = value.Recurrence;
                    appoint.OwnerId = value.OwnerId;
                    appoint.RecurrenceRule = value.RecurrenceRule;
                }
                db.SubmitChanges();
            }

            if (deleted != null && deleted.Count > 0)
            {
                foreach (ScheduleAppointment dele in deleted)
                {
                    var app = db.ScheduleAppointments.ToList().Where(c => c.Id == Convert.ToInt32(dele.Id)).FirstOrDefault();
                    if (app != null)
                    {
                        db.ScheduleAppointments.DeleteOnSubmit(app);
                    }
                }
                db.SubmitChanges();
            }
            return db.ScheduleAppointments.ToList();
        }
        [WebMethod]
        [ScriptMethod(ResponseFormat = ResponseFormat.Json)]
        public static List<ScheduleAppointment> InsertData(ScheduleAppointment value)
        {
            ScheduleDataDataContext db = new ScheduleDataDataContext();

            int intMax = db.ScheduleAppointments.ToList().Count > 0 ? db.ScheduleAppointments.ToList().Max(p => p.Id) : 0;
            DateTime startTime = Convert.ToDateTime(value.StartTime);
            DateTime endTime = Convert.ToDateTime(value.EndTime);
            ScheduleAppointment appoint = new ScheduleAppointment()
            {
                Id = intMax + 1,
                StartTime = startTime,
                EndTime = endTime,
                Subject = value.Subject,
                AllDay = value.AllDay,
                Recurrence = value.Recurrence,
                RecurrenceRule = value.RecurrenceRule,
                OwnerId = value.OwnerId
            };
            db.ScheduleAppointments.InsertOnSubmit(appoint);
            db.SubmitChanges();
            return db.ScheduleAppointments.ToList();
        }
        [WebMethod]
        [ScriptMethod(ResponseFormat = ResponseFormat.Json)]
        public static List<ScheduleAppointment> RemoveData(string key)
        {
            ScheduleDataDataContext db = new ScheduleDataDataContext();
            ScheduleAppointment app = db.ScheduleAppointments.Where(c => c.Id == Convert.ToInt32(key)).FirstOrDefault();
            if (app != null) db.ScheduleAppointments.DeleteOnSubmit(app);
            db.SubmitChanges();
            return db.ScheduleAppointments.ToList();
        }

        [WebMethod]
        [ScriptMethod(ResponseFormat = ResponseFormat.Json)]
        public static List<ScheduleAppointment> UpdateData(ScheduleAppointment value)
        {
            ScheduleDataDataContext db = new ScheduleDataDataContext();
            var filterData = db.ScheduleAppointments.Where(c => c.Id == Convert.ToInt32(value.Id));
            if (filterData.Count() > 0)
            {
                DateTime startTime = Convert.ToDateTime(value.StartTime);
                DateTime endTime = Convert.ToDateTime(value.EndTime);
                ScheduleAppointment appoint = db.ScheduleAppointments.Single(A => A.Id == Convert.ToInt32(value.Id));
                appoint.StartTime = startTime;
                appoint.EndTime = endTime;
                appoint.Subject = value.Subject;
                appoint.AllDay = value.AllDay;
                appoint.Recurrence = value.Recurrence;
                appoint.RecurrenceRule = value.RecurrenceRule;
                appoint.OwnerId = value.OwnerId;
            }
            db.SubmitChanges();
            return db.ScheduleAppointments.ToList();
        }
    }
}